==> 0.9.0+20150831-1.zip: lxqt-runner-packaging/translations/lxqt-runner_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Настройки ускорителя запуска</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Позиция:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Показывать на:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Сочетание клавиш:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation>Верхней границе экрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation>В центре экрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Активном экране</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Всегда на %1 экране</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Ускоритель запуска программ </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="92"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="96"/>
        <source>Clear History</source>
        <translation>Очистить историю</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="337"/>
        <source>Show/hide runner dialog</source>
        <translation>Показать/скрыть окно ускорителя</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="388"/>
        <source>History</source>
        <translation>Из истории</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="779"/>
        <source>Mathematics</source>
        <translation>Математика</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="840"/>
        <source>Power Management</source>
        <translation>Управление энергопотреблением</translation>
    </message>
</context>
</TS>

==> 0.10.0-2.zip: lxqt-runner-packaging/translations/lxqt-runner_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Настройки ускорителя запуска</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Позиция:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Показывать на:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Сочетание клавиш:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation>Верхней границе экрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation>В центре экрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Активном экране</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Всегда на %1 экране</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Ускоритель запуска программ </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="93"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="97"/>
        <source>Clear History</source>
        <translation>Очистить историю</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="345"/>
        <source>Show/hide runner dialog</source>
        <translation>Показать/скрыть окно ускорителя</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="443"/>
        <source>History</source>
        <translation>Из истории</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="801"/>
        <source>Mathematics</source>
        <translation>Математика</translation>
    </message>
    <message>
        <source>Power Management</source>
        <translation type="vanished">Управление энергопотреблением</translation>
    </message>
</context>
</TS>
